@@ -1,32 +1,21 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2019-2020, Maximilian Köhl <koehl@cs.uni-saarland.de>
+# Copyright (C) 2019-2021, Saarland University
+# Copyright (C) 2019-2021, Maximilian Köhl <koehl@cs.uni-saarland.de>
 
 from __future__ import annotations
 
-from .. import errors
 
-
-class ModelingError(errors.MombaError):
-    pass
+class ModelingError(Exception):
+    """
+    A general modeling error.
+    """
 
 
 class InvalidTypeError(ModelingError):
     pass
 
 
-class NotAConstantError(ModelingError):
-    pass
-
-
-class NotAVariableError(ModelingError):
-    pass
-
-
-class InvalidOperationError(ModelingError):
-    pass
-
-
 class IncompatibleAssignmentsError(ModelingError):
     pass
 
@@ -41,3 +30,7 @@ class InvalidDeclarationError(ModelingError):
 
 class UnboundIdentifierError(ModelingError):
     pass
+
+
+class NotFoundError(ModelingError):
+    pass
